@@ -1,5 +1,5 @@
 /* David Leonard, 2002. Public domain. */
-/* $Id: abbrev.c 978 2006-01-27 15:01:08Z d $ */
+/* $Id: abbrev.c 1207 2012-03-04 14:22:05Z d $ */
 
 /*
  * Abbreviations are a way of collapsing similar packet
@@ -24,8 +24,8 @@
 #define iswhite(c)	((c) == ' ' || (c) == '\t')
 
 struct pattern {
-	const char *name;
-	const char *pattern;
+	char *name;
+	char *pattern;  /* pointer into name */
 };
 
 static int npatterns;
@@ -193,3 +193,15 @@ abbrev_add_default_files()
 	}
 	abbrev_add_file(PATH_PKTSTATRC, 1);
 }
+
+void
+abbrev_free()
+{
+	while (npatterns--)
+	    free(patterns[npatterns].name);
+	if (allocpatterns) {
+	    free(patterns);
+	    allocpatterns = 0;
+	}
+	npatterns = 0;
+}
