@@ -1,5 +1,5 @@
 /* David Leonard, 2002. Public domain. */
-/* $Id: display.c 1196 2007-09-04 13:49:33Z d $ */
+/* $Id: display.c 1212 2012-03-04 14:38:41Z d $ */
 
 /*
  * This compilation unit uses curses to display the current
@@ -316,7 +316,7 @@ display_update(period)
 	        replybuf[replybuflen] = 0;
 		switch (prompting) {
 		case 'w':
-		    sscanf(replybuf, "%u", &wflag);
+		    sscanf(replybuf, "%d", &wflag);
 		    break;
 		}
 	    	prompting = 0;
@@ -367,26 +367,11 @@ display_update(period)
 		clearflows = 1;
 		break;
 	case 'r':			/* reset stats */
-		total_octets = 0;
-		total_packets = 0;
-		total_time = 0;
-		maxbps = -1;
-		minbps = -1;
-		maxpps = -1;
-		minpps = -1;
+		display_reset();
 		period = 0;
-		while (nflows)		/* clear flows now */
-			flow_del(flows);
-#if HAVE_EXP
-		for (i = 0; i < 3; i++)	/* clear averages */
-			avg[i] = avg_pkt[i] = 0;
-#endif
-		ip_reset();
-		udp_reset();
-		tcp_reset();
 		break;
 	case 'w':
-		snprintf(prompt, sizeof prompt, "Wait interval [%u]", wflag);
+		snprintf(prompt, sizeof prompt, "Wait interval [%d]", wflag);
 		prompting = ch;
 		showhelp = 0;
 		replybuflen = 0;
@@ -690,3 +675,23 @@ printhelp()
 	}
 	printw(" - pktstat %s", version);
 }
+
+void
+display_reset()
+{
+	total_octets = 0;
+	total_packets = 0;
+	total_time = 0;
+	maxbps = -1;
+	minbps = -1;
+	maxpps = -1;
+	minpps = -1;
+	flow_free();
+	#if HAVE_EXP
+	for (i = 0; i < 3; i++)	/* clear averages */
+		avg[i] = avg_pkt[i] = 0;
+	#endif
+	ip_reset();
+	udp_reset();
+	tcp_reset();
+}
