@@ -1,12 +1,15 @@
 /* David Leonard, 2002. Public domain. */
-/* $Id: ipx.c 978 2006-01-27 15:01:08Z d $ */
+/* $Id: ipx.c 1172 2006-11-11 13:32:14Z d $ */
 
 #if HAVE_CONFIG_H
 # include "config.h"
 #endif
 
+#if HAVE_NETIPX_IPX_H
+
 #if STDC_HEADERS
 # include <stdio.h>
+# include <string.h>
 #endif
 #if HAVE_SYS_TYPES_H
 # include <sys/types.h>
@@ -20,6 +23,9 @@
 #if HAVE_NETIPX_IPX_H
 # include <netipx/ipx.h>
 #endif
+#if HAVE_ARPA_INET_H
+# include <arpa/inet.h>
+#endif
 
 #include "compat.h"
 #include "tag.h"
@@ -171,3 +177,5 @@ ipx_tag(p, end)
  * - http://www.protocols.com/pbook/novel.htm
  * - 802.2 over IPX: RFC1132
  */
+
+#endif /* HAVE_NETIPX_IPX_H */
