@@ -1,5 +1,5 @@
 /* David Leonard, 2004. Public domain. */
-/* $Id: machendian.h 614 2004-03-13 16:51:21Z d $ */
+/* $Id: machendian.h 1205 2012-03-04 14:10:49Z d $ */
 
 /*
  * Machine-dependent types and endian conversion.
@@ -37,7 +37,7 @@
 # endif
 #endif
 
-#if defined(__linux__)
+#if defined(__linux__) || defined(__FreeBSD_kernel__)
 # include <endian.h>
 # include <byteswap.h>
 # define swap16(x) bswap_16(x)
