@@ -1,5 +1,5 @@
 /* David Leonard, 2002. Public domain. */
-/* $Id: main.c 1196 2007-09-04 13:49:33Z d $ */
+/* $Id: main.c 1208 2012-03-04 14:24:56Z d $ */
 
 /*
  * The main module. Here we process command line arguments, and
@@ -41,6 +41,9 @@
 # endif
 #endif
 
+#include <assert.h>
+
+#include "resize.h"
 #include "compat.h"
 #include "main.h"
 #include "tag.h"
@@ -82,6 +85,20 @@ static struct timeval starttime;
         } while (0)
 #endif
 
+void set_canary(volatile unsigned char *canary, size_t sz) {
+    int i;
+    for (i = 0; i < sz; i++)
+	canary[i] = i & 0xff;
+}
+void check_canary(const volatile unsigned char *canary, size_t sz) {
+    int i;
+    for (i = 0; i < sz; i++)
+	if (canary[i] != (i & 0xff)) {
+	    fprintf(stderr, "\nCANARY FAILED at %p[%u]\n", canary, i);
+	    abort();
+	}
+}
+
 /*
  * Receive a packet from libpcap and determine its category tag.
  * This is called directly from libpcap.
@@ -97,10 +114,16 @@ upcall_from_pcap(context, hdr, data)
 		(const char *(*)(const char *, const char *))context;
 	struct flow *flow;
 
+	volatile auto unsigned char canary[8192];
+
+	set_canary(canary, sizeof canary);
+
 	/* 'Tag' this packet. ie identify it in a human-readable way */
 	tag = abbrev_tag((*fn)((const char *)data, 
 		(const char *)data + hdr->caplen));
 
+	check_canary(canary, sizeof canary);
+
 	/* Find which tracked flow the packet belongs to and account it */
 	flow = findflow(tag);
 	flow->octets += hdr->len;
@@ -110,6 +133,14 @@ upcall_from_pcap(context, hdr, data)
 	flow->total_packets++;
 }
 
+/* Clean up pcap resources */
+pcap_t *pcap_cleanup_ptr;
+void
+pcap_cleanup()
+{
+    pcap_close(pcap_cleanup_ptr);
+}
+
 /* main */
 int
 main(argc, argv)
@@ -131,6 +162,10 @@ main(argc, argv)
 	int exprlen;
 	int blankAflag = 0;
 
+	free(malloc(1));
+
+	atexit(abbrev_free);
+
 	/* Process command line options */
 	while ((ch = getopt(argc, argv, "1A:a:BcEFi:k:lm:npPtTw:")) != -1)
 		switch (ch) {
@@ -224,6 +259,8 @@ main(argc, argv)
 	p = pcap_open_live(interface, snaplen, Pflag ? 0 : 1, 10, errbuf);
 	if (!p) 
 		errx(1, "%s", errbuf);
+	pcap_cleanup_ptr = p;
+	atexit(pcap_cleanup);
 
 	/* XXX should drop privileges here before opening files */
 	/* if (issetugid()) seteuid(getuid()); */
@@ -304,6 +341,7 @@ main(argc, argv)
 	if (gettimeofday(&starttime, NULL) == -1)
 		err(1, "gettimeofday");
 	flow_zero();
+	atexit(display_reset);
 	if (!oneflag) {
 	    display_open(interface, expr);
 	    atexit(display_close);
@@ -343,7 +381,7 @@ main(argc, argv)
 			cnt = pcap_dispatch(p, -1, upcall_from_pcap,
 				(u_char *)fn);
 			if (cnt == -1) {
-				snprintf(errmsg, sizeof errmsg, pcap_geterr(p));
+				snprintf(errmsg, sizeof errmsg, "%s", pcap_geterr(p));
 				error = 1;
 			}
 		}
@@ -389,6 +427,5 @@ main(argc, argv)
 		}
 	}
 
-	pcap_close(p);
 	exit(0);
 }
