@@ -1,5 +1,5 @@
 /* David Leonard, 2003. Public domain. */
-/* $Id: sll.c 978 2006-01-27 15:01:08Z d $ */
+/* $Id: sll.c 1162 2006-11-10 05:34:53Z d $ */
 
 #if HAVE_CONFIG_H
 # include "config.h"
@@ -17,6 +17,9 @@
 #if HAVE_SYS_SOCKET_H
 # include <sys/socket.h>
 #endif
+#if HAVE_ARPA_INET_H
+# include <arpa/inet.h>
+#endif
 
 #include "compat.h"
 #include "tag.h"
