@@ -1,5 +1,5 @@
 /* David Leonard, 2002. Public domain. */
-/* $Id: tcp.c 1189 2007-08-30 09:22:19Z d $ */
+/* $Id: tcp.c 1209 2012-03-04 14:31:19Z d $ */
 
 #if HAVE_CONFIG_H
 # include "config.h"
@@ -19,7 +19,7 @@
 #if HAVE_SYS_TIME_H
 # include <sys/time.h>
 #endif
-#if defined(__linux__)
+#if defined(__linux__) || defined(__GLIBC__)
 # define __FAVOR_BSD
 #endif
 #if HAVE_NETINET_IN_H
@@ -203,6 +203,9 @@ tcp_tag(p, end, ip, ip6)
 				& 0xffffffffUL;
 
 	switch (dport) {
+	case 25:
+		tcp_smtp(f, data, end, 1);
+		break;
 	case 80:
 	case 8080:
 	case 3127:
@@ -254,14 +257,15 @@ tcp_tag(p, end, ip, ip6)
 			for (d = data; d < end && *d != '\r' && *d != '\n'; d++)
 				;
 			snprintf(f->desc, sizeof f->desc, "%.*s",
-				 d - data, data);
+				 (int)(d - data), data);
 			/* Copy the desc to the data flow if it is known */
 			if (ftp.datatag[0] != '\0'  &&
 			    strcmp(ftp.ctltag, tag) == 0)
 			{
 			    struct flow *f2 = findflow(ftp.datatag);
 			    snprintf(f2->desc, sizeof f2->desc,
-				"ftp-data: %.*s", d - data - 5, data + 5);
+				"ftp-data: %.*s", 
+                                (int)(d - data) - 5, data + 5);
 			    ftp.ctltag[0] = '\0';
 			    ftp.datatag[0] = '\0';
 			}
